# ks33requests

## 概述

一个很简单的、适用于 [金山云][] 对象存储([KS3][])的 [Python][]3 客户端。

[金山云][] 官方提供了 [KS3][] 的 [Python][] SDK，但在我启动这个项目(2019-06-10)时，仅提供 [Python][]2 SDK。

考虑到 [Python][]2 已经接近其生命周期的终点，我制作了这个简单的 [Python]3 [KS3][] 客户端用于相关项目。

## 如何使用

参见 [guide](notebooks/guide.ipynb)

## 说明文档

- [INSTALL](INSTALL.md)
- [CHANGELOG](CHANGELOG.md)
- [CONTRIBUTING](CONTRIBUTING.md)
- [AUTHORS](AUTHORS.md)

[Python]: https://python.org/
[金山云]: https://www.ksyun.com/
[KS3]: https://www.ksyun.com/post/product/KS3 "金山对象存储（Kingsoft Standard Storage Service，简称KS3）"
